import logging
import typer

from mlstfest import __version__, __title__


app = typer.Typer()
LOG = logging.getLogger(__name__)


@app.callback()
def callback(debug: bool = False):
    """
    mlstfest - Strain type assignment to novel microbe sequences
    """
    if debug:
        typer.echo("DEBUG logging enabled")
        logging.basicConfig(level=logging.DEBUG)


@app.command()
def version():
    """
    Print the version
    """
    typer.echo("%s, version %s" % (__title__, __version__))



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mlstfest']

package_data = \
{'': ['*']}

install_requires = \
['typer>=0.4.2,<0.5.0']

entry_points = \
{'console_scripts': ['mlstfest = mlstfest.main:app']}

setup_kwargs = {
    'name': 'mlstfest',
    'version': '0.1.0',
    'description': 'mlstfest can assign a strain type to novel microbial WGS data',
    'long_description': None,
    'author': 'henningonsbring',
    'author_email': 'henning.onsbring@scilifelab.se',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
